<?php
declare(strict_types=1);

namespace GamesShop\Routing;

use GamesShop\ContainerHandler;
use GamesShop\Paths;
use Laminas\Diactoros\Response;
use Mimey\MimeTypes;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;

final class ResourceRoute
{
    private const array RESOURCE_EXTENSIONS = [
        'js',
        'css',
        'ttf', 'woff', 'woff2',
        'gif', 'svg', 'png', 'jpg'
    ];

    public function __invoke(ServerRequestInterface $request, array $args): ResponseInterface {

        $filePath = Paths::PUBLIC_PATH . $request->getUri()->getPath();

        if (!file_exists($filePath)) {
            $response = new Response(status: 404);
            $response->getBody()->write('File not found');

            return $response;
        }

        $mimey = ContainerHandler::get(MimeTypes::class);
        $response = new Response(
            headers: [
                'Content-Type' => $mimey->getMimeType(pathinfo($filePath, PATHINFO_EXTENSION)),
                'Cache-Control' => 'public, max-age=3600, must-revalidate',
            ]
        );
        $response->getBody()->write(file_get_contents($filePath));

        return $response;
    }

    public static function addRouteEntry(\League\Route\Router $router): void {
        $joinedResourceExtensions = implode('|', self::RESOURCE_EXTENSIONS);
        $router->addPatternMatcher('resource', ".+[{$joinedResourceExtensions}]");

        $router->get('/{resource:resource}', self::class);
    }
}