<?php
declare(strict_types=1);

namespace GamesShop\Routing;

use GamesShop\ContainerHandler;
use GamesShop\Login\LoginHandler;
use GamesShop\Templates\TemplateEngine;
use Laminas\Diactoros\Response;
use Laminas\Diactoros\ServerRequestFactory;
use League\Container\Container;
use League\Route\Strategy\ApplicationStrategy;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;

final class Router
{
    public function route()
    {
        $request = ServerRequestFactory::fromGlobals(
            $_SERVER, $_GET, $_POST, $_COOKIE, $_FILES
        );
        $router = new \League\Route\Router;
        $strategy = (new ApplicationStrategy)->setContainer(ContainerHandler::getInstance());
        $router->setStrategy($strategy);

        IndexRoute::applyRoutes($router);
        LoginRoutes::addRoutes($router);
        ResourceRoute::addRouteEntry($router);

        try {
            return $router->dispatch($request);
        } catch (\League\Route\Http\Exception\NotFoundException $e) {
            return (new ErrorRoute())->renderErrorPage(404);
        }
    }
}